@@ -176,6 +176,19 @@ pub trait IdTable<UidType: PartialEq, Row: TableRow>: Table<Row> {
         val
     }
     
+    /// Returns a mutable reference to a row
+    fn get_row_mut(&mut self, uid: UidType) -> Option<&mut Row> {
+        let val: Option<&mut Row> = self.get_rows_mut().iter_mut().find_map(|row| {
+            if Self::get_id_from_row(row) == uid {
+                Some(row)
+            }  else {
+                None
+            }
+        });
+    
+        val
+    }
+    
     // TODO
     // /// Searches through the sorted rows using the uid. Only works if the rows have been sorted first,
     // /// the [`sort`](table_rows::core::Table::sort) function can help with this.
